@@ -85,7 +85,7 @@ class SelectUuid(object):
             start_time = int(time.time())
             # 查询poi到访数据,创建arrvie视图
             sql_arrive = f"""
-                select a.uuid,a.poi_id,a.create_time as timestamp ,a.date_str,
+                select a.uuid,a.poi_id,a.create_time as timestamp ,a.date_str,a.num,
                 b.fisrt_c_name,b.second_c_name,b.third_c_name,b.p_name as poi_name
                 from (select c.*
                 from (select uuid,poi_id,create_time,
@@ -109,7 +109,7 @@ class SelectUuid(object):
 
             # 查询poi离店数据,创建leave视图
             sql_leave = f"""
-                select a.uuid, a.date_str,a.timestamp,
+                select a.uuid, a.date_str,a.timestamp,a.num,
                 b.p_name as poi_name,b.fisrt_c_name,b.second_c_name,b.third_c_name,b.p_id as poi_id
                 from (select c.*
                 from (select uuid, poi_id,timestamp,
